@@ -48,12 +48,15 @@ def _has_npm_available() -> bool:
             return True
 
         # Try running npm.cmd directly
-        try:
-            result = subprocess.run(['npm.cmd', '--version'], capture_output=True, timeout=5)
-            if result.returncode == 0:
-                return True
-        except:
-            pass
+        npm_cmd_path = shutil.which('npm.cmd')
+        if npm_cmd_path:
+            try:
+                result = subprocess.run([npm_cmd_path, '--version'], capture_output=True, timeout=5)
+                if result.returncode == 0:
+                    return True
+            except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
+                # npm.cmd not found or execution failed - continue to check other locations
+                pass
 
         # Check common Windows install locations for npm.cmd
         common_paths = [
@@ -80,21 +83,28 @@ def _has_pip_available() -> bool:
     # Windows: Python's pip is always available via 'py -m pip'
     import subprocess
     import platform
+    import shutil
     if platform.system() == 'Windows':
-        try:
-            result = subprocess.run(['py', '-m', 'pip', '--version'], capture_output=True, timeout=5)
-            return result.returncode == 0
-        except:
-            pass
+        py_path = shutil.which('py')
+        if py_path:
+            try:
+                result = subprocess.run([py_path, '-m', 'pip', '--version'], capture_output=True, timeout=5)
+                return result.returncode == 0
+            except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
+                # py launcher not available - continue to Unix fallback
+                pass
 
     # Unix: Try python3 -m pip
     try:
         import subprocess
-        result = subprocess.run(['python3', '-m', 'pip', '--version'], capture_output=True, timeout=5)
-        return result.returncode == 0
-    except:
+        import shutil
+        python3_path = shutil.which('python3')
+        if python3_path:
+            result = subprocess.run([python3_path, '-m', 'pip', '--version'], capture_output=True, timeout=5)
+            return result.returncode == 0
+    except (subprocess.SubprocessError, FileNotFoundError, OSError, subprocess.TimeoutExpired):
         pass
-
+    # python3 not available or pip not installed
     return False
 
 
@@ -124,13 +134,15 @@ def _safe_print(*args, **kwargs):
 
         try:
             _original_print(*safe_args, **kwargs)
-        except:
+        except Exception:
             # Last resort: plain print with ASCII-only
             ascii_text = ' '.join(str(a).encode('ascii', 'ignore').decode('ascii') for a in safe_args)
             try:
                 print(ascii_text)
-            except:
-                pass  # Give up silently
+            except Exception:
+                # Final fallback failed - suppress to prevent crash during output
+                # This is intentionally silent as there's nothing more we can do
+                pass
 
 console.print = _safe_print
 
@@ -684,14 +696,18 @@ def _install_tools(tools: list, use_latest: bool = False):
                 # First check if Node.js is already installed
                 console.print("\n[cyan]Checking for existing Node.js installation...[/cyan]")
                 nodejs_already_installed = False
-                try:
-                    import subprocess
-                    node_check = subprocess.run(['node', '--version'], capture_output=True, text=True, timeout=5)
-                    if node_check.returncode == 0:
-                        nodejs_already_installed = True
-                        console.print(f"[green]✓[/green] Node.js found: {node_check.stdout.strip()}")
-                        console.print("[yellow]   But npm not in PATH. Attempting to fix...[/yellow]")
-                except:
+                node_path = shutil.which('node')
+                if node_path:
+                    try:
+                        import subprocess
+                        node_check = subprocess.run([node_path, '--version'], capture_output=True, text=True, timeout=5)
+                        if node_check.returncode == 0:
+                            nodejs_already_installed = True
+                            console.print(f"[green]✓[/green] Node.js found: {node_check.stdout.strip()}")
+                            console.print("[yellow]   But npm not in PATH. Attempting to fix...[/yellow]")
+                    except:
+                        pass
+                if not nodejs_already_installed:
                     console.print("[dim]   Node.js not found, installing...[/dim]")
 
                 if not nodejs_already_installed:
@@ -701,27 +717,29 @@ def _install_tools(tools: list, use_latest: bool = False):
                 winget_installer = WingetInstaller()
                 nodejs_success = False
 
-                try:
-                    import subprocess
-                    result = subprocess.run(
-                        ['winget', 'install', '--id', 'OpenJS.NodeJS', '--accept-source-agreements', '--accept-package-agreements'],
-                        capture_output=True,
-                        text=True,
-                        timeout=120
-                    )
-                    output = result.stdout.lower() if result.stdout else ''
-                    nodejs_success = (
-                        result.returncode == 0 or
-                        'already installed' in output or
-                        'no available upgrade found' in output
-                    )
+                winget_path = shutil.which('winget')
+                if winget_path:
+                    try:
+                        import subprocess
+                        result = subprocess.run(
+                            [winget_path, 'install', '--id', 'OpenJS.NodeJS', '--accept-source-agreements', '--accept-package-agreements'],
+                            capture_output=True,
+                            text=True,
+                            timeout=120
+                        )
+                        output = result.stdout.lower() if result.stdout else ''
+                        nodejs_success = (
+                            result.returncode == 0 or
+                            'already installed' in output or
+                            'no available upgrade found' in output
+                        )
 
-                    # Show winget output for debugging
-                    if result.returncode != 0:
-                        console.print(f"[dim]Winget output: {result.stdout[:300]}[/dim]")
-                except Exception as e:
-                    nodejs_success = False
-                    console.print(f"[red]Error during installation: {str(e)[:100]}[/red]")
+                        # Show winget output for debugging
+                        if result.returncode != 0:
+                            console.print(f"[dim]Winget output: {result.stdout[:300]}[/dim]")
+                    except Exception as e:
+                        nodejs_success = False
+                        console.print(f"[red]Error during installation: {str(e)[:100]}[/red]")
 
                 if nodejs_success:
                     console.print("[green]✅ Node.js installed successfully[/green]")
@@ -734,17 +752,22 @@ def _install_tools(tools: list, use_latest: bool = False):
 
                     # Verify npm is now available
                     console.print("\n[cyan]Checking for npm...[/cyan]")
-                    npm_path = shutil.which('npm')
+                    # On Windows, look for npm.cmd explicitly to avoid shell=True
+                    if platform_info.os_type.value == 'windows':
+                        npm_path = shutil.which('npm.cmd') or shutil.which('npm')
+                    else:
+                        npm_path = shutil.which('npm')
+
                     if npm_path:
                         console.print(f"[green]✓[/green] npm found at: {npm_path}")
-                        # Verify npm works (use shell=True on Windows for .cmd files)
+                        # Verify npm works (no shell=True needed with explicit path)
                         try:
                             npm_version_check = subprocess.run(
-                                ['npm', '--version'],
+                                [npm_path, '--version'],
                                 capture_output=True,
                                 text=True,
                                 timeout=5,
-                                shell=True  # Required for .CMD files on Windows
+                                shell=False
                             )
                             if npm_version_check.returncode == 0:
                                 console.print(f"[green]✓[/green] npm version: {npm_version_check.stdout.strip()}")
@@ -796,7 +819,7 @@ def print_banner():
 ║                                                                    ║
 ║          🐍🐍🐍 MEDUSA v{__version__} - Security Guardian 🐍🐍🐍           ║
 ║                                                                    ║
-║         Universal Scanner with 40+ Specialized Analyzers          ║
+║         Universal Scanner with 43+ Specialized Analyzers          ║
 ║           One look from Medusa stops vulnerabilities dead          ║
 ║                                                                    ║
 ╚════════════════════════════════════════════════════════════════════╝[/bold magenta]
@@ -810,7 +833,7 @@ def print_banner():
 ║                                                                    ║
 ║              MEDUSA v{__version__} - Security Guardian                 ║
 ║                                                                    ║
-║         Universal Scanner with 40+ Specialized Analyzers          ║
+║         Universal Scanner with 43+ Specialized Analyzers          ║
 ║           One look from Medusa stops vulnerabilities dead          ║
 ║                                                                    ║
 ╚════════════════════════════════════════════════════════════════════╝[/bold magenta]
