@@ -40,8 +40,7 @@ class SQLScanner(BaseScanner):
         try:
             # Run SQLFluff lint with JSON output
             result = subprocess.run(
-                [
-                    "sqlfluff", "lint",
+                [str(self.tool_path), "lint",
                     "--format", "json",
                     "--dialect", "ansi",  # Default to ANSI SQL
                     str(file_path)
